@@ -40,3 +40,6 @@ def get_formatted_filesize(value, precision=1, size_postfix=['KB', 'MB', 'GB', '
       if tmp.endswith('.0'): tmp = tmp.rsplit('.')[0]
       result = '%s%s' % (tmp, size_postfix[x])
   return result
+
+def get_formatted_percentage(a, b, precision=1):
+  return min(100.0, round(100.0 * a / b, precision))
